--- cygport-ruby/ruby.cygport	2023-04-20 05:03:44
+++ playground/ruby.cygport	2023-04-19 22:52:50
@@ -1,5 +1,5 @@
 NAME="ruby"
-VERSION=2.6.4
+VERSION=3.2.2
 RELEASE=1
 CATEGORY="Interpreters Ruby"
 SUMMARY="Interpreted object-oriented scripting language"
@@ -7,39 +7,42 @@
 object-oriented programming.  It has many features to process text files and
 to do system management tasks (as in Perl).  It is simple, straight-forward,
 and extensible."
-HOMEPAGE="http://www.ruby-lang.org/"
-SRC_URI="https://cache.ruby-lang.org/pub/ruby/${VERSION%.*}/ruby-${VERSION}.tar.bz2"
+HOMEPAGE="https://www.ruby-lang.org/"
+SRC_URI="https://cache.ruby-lang.org/pub/ruby/${VERSION%.*}/ruby-${VERSION}.tar.gz"
 PATCH_URI="
 	fedora/ruby-2.3.0-ruby_version.patch
 	fedora/ruby-2.1.0-Prevent-duplicated-paths-when-empty-version-string-i.patch
 	fedora/ruby-2.1.0-Enable-configuration-of-archlibdir.patch
 	fedora/ruby-2.1.0-always-use-i386.patch
 	fedora/ruby-2.1.0-custom-rubygems-location.patch
-	fedora/ruby-1.9.3-mkmf-verbose.patch
-	fedora/ruby-2.2.3-Generate-preludes-using-miniruby.patch
-	fedora/ruby-2.6.0-config-support-include-directive.patch
-	fedora/ruby-2.6.0-use-larger-keys-for-SSL-tests.patch
-	2.0.0-cygwin-configure.patch
+	fedora/ruby-2.7.0-Initialize-ABRT-hook.patch
+	fedora/ruby-3.1.0-Don-t-query-RubyVM-FrozenCore-for-class-path.patch
+	fedora/ruby-2.7.1-Timeout-the-test_bug_reporter_add-witout-raising-err.patch
+	fedora/ruby-3.2.0-Revert-Fix-test-syntax-suggest-order.patch
+	fedora/ruby-3.2.0-Revert-Test-syntax_suggest-by-make-check.patch
 	2.0.0-cygwin-rubygems.patch
 	2.0.0-pkgconfig-version.patch
 	2.5.1-win32-resolv.patch
 "
+LICENSE="Ruby"
 
+BUILD_REQUIRES="libcrypt-devel libffi-devel libgmp-devel libreadline-devel libssl-devel libyaml-devel rubygems zlib-devel"
+
 PKG_NAMES="${NAME} ${NAME}-devel ${NAME}-doc ${NAME}-tcltk"
-ruby_REQUIRES="rubygems ruby-did_you_mean ca-certificates"
-ruby_OBSOLETES="ruby-bigdecimal ruby-bundler ruby-io-console ruby-json ruby-psych"
+ruby_REQUIRES="ca-certificates"
+ruby_OBSOLETES="ruby-bigdecimal ruby-bundler ruby-io-console ruby-json ruby-psych ruby-racc"
 ruby_CONTENTS="
-	--exclude=capi
 	usr/bin/bundle*
 	usr/bin/cygruby*.dll
 	usr/bin/erb
 	usr/bin/irb
+	usr/bin/racc
 	usr/bin/ruby.exe
+	usr/bin/rubyw.exe
 	usr/lib/ruby/
 	usr/share/doc/
-	usr/share/gems/specifications/default/
+	usr/share/gems/
 	usr/share/man/man1/*
-	usr/share/man/man5/*
 	usr/share/ruby/
 	var/lib/rebase/
 "
@@ -49,14 +52,16 @@
 	usr/lib/libruby*.dll.a
 	usr/lib/pkgconfig/ruby*.pc
 "
-ruby_doc_OBSOLETES="ruby-bigdecimal-doc ruby-bundler-doc ruby-io-console-doc ruby-json-doc ruby-psych-doc"
+ruby_doc_OBSOLETES="ruby-bigdecimal-doc ruby-bundler-doc ruby-io-console-doc ruby-json-doc ruby-psych-doc ruby-racc-doc"
 ruby_doc_CONTENTS="usr/share/ri/"
 ruby_tcltk_SUMMARY="Obsolete package"
 ruby_tcltk_REQUIRES="ruby-tk"
-ruby_debuginfo_OBSOLETES="ruby-bigdecimal-debuginfo ruby-io-console-debuginfo ruby-json-debuginfo ruby-psych-debuginfo"
+ruby_debuginfo_OBSOLETES="ruby-bigdecimal-debuginfo ruby-io-console-debuginfo ruby-json-debuginfo ruby-psych-debuginfo ruby-racc-debuginfo"
 
-DIFF_EXCLUDES=".document revision.h"
+DIFF_EXCLUDES="install-sh"
 
+export RUBYOPT="-I/usr/share/rubygems"
+
 src_compile() {
 	local ruby_version=${VERSION%.*}
 
@@ -83,9 +88,10 @@
 	cygmake
 }
 
+# https://bugs.ruby-lang.org/issues/15465
 src_test() {
 	cd ${B}
-	make test
+#	make test
 }
 
 src_install() {
@@ -101,6 +107,9 @@
 		-e 's|/$(ruby_version)||g' \
 		${D}${rbarchdir}/rbconfig.rb
 
+	# move gems to rbgemdir
+	mv -f ${D}/usr/share/ruby/${ruby_version}/gems ${D}${rbgemdir}
+
 	# the libraries are in default locations so no need for gem wrappers
 	mv -f ${D}${rbgemdir}/gems/*/exe/* ${D}/usr/bin/
 
@@ -109,18 +118,34 @@
 	# rubygems
 	rm -f  ${D}/usr/bin/gem
 	rm -fr ${D}/usr/share/rubygems/
-	# bundler: certs
-	rm -fr ${D}${rblibdir}/bundler/ssl_certs/
-	# did_you_mean (since 2.3)
-	rm -fr ${D}${rbgemdir}/gems/did_you_mean-*
-	rm -f  ${D}${rbgemdir}/specifications/did_you_mean-*.gemspec
+
+	# debug
+	rm -f  ${D}/usr/bin/rdbg
+	rm -fr ${D}${rbgemdir}/extensions/*/${ruby_version}.0/debug-*
+	rm -fr ${D}${rbgemdir}/gems/debug-*
+	rm -f  ${D}${rbgemdir}/specifications/debug-*.gemspec
 	# minitest
 	rm -fr ${D}${rbgemdir}/gems/minitest-*
 	rm -f  ${D}${rbgemdir}/specifications/minitest-*.gemspec
-	# net-telnet (since 2.3)
-	rm -fr ${D}${rbgemdir}/gems/net-telnet-*
-	rm -f  ${D}${rbgemdir}/specifications/net-telnet-*.gemspec
-	# power_assert (since 2.3)
+	# matrix
+	rm -fr ${D}${rbgemdir}/gems/matrix-*
+	rm -f  ${D}${rbgemdir}/specifications/matrix-*.gemspec
+	# net-ftp
+	rm -fr ${D}${rbgemdir}/gems/net-ftp-*
+	rm -f  ${D}${rbgemdir}/specifications/net-ftp-*.gemspec
+	# net-imap
+	rm -fr ${D}${rbgemdir}/gems/net-imap-*
+	rm -f  ${D}${rbgemdir}/specifications/net-imap-*.gemspec
+	# net-pop
+	rm -fr ${D}${rbgemdir}/gems/net-pop-*
+	rm -f  ${D}${rbgemdir}/specifications/net-pop-*.gemspec
+	# net-smtp
+	rm -fr ${D}${rbgemdir}/gems/net-smtp-*
+	rm -f  ${D}${rbgemdir}/specifications/net-smtp-*.gemspec
+	# prime
+	rm -fr ${D}${rbgemdir}/gems/prime-*
+	rm -f  ${D}${rbgemdir}/specifications/prime-*.gemspec
+	# power_assert
 	rm -fr ${D}${rbgemdir}/gems/power_assert-*
 	rm -f  ${D}${rbgemdir}/specifications/power_assert-*.gemspec
 	# rake
@@ -128,18 +153,31 @@
 	rm -f  ${D}/usr/share/man/man1/rake.*
 	rm -fr ${D}${rbgemdir}/gems/rake-*
 	rm -f  ${D}${rbgemdir}/specifications/rake-*.gemspec
+	# rbs
+	rm -f  ${D}/usr/bin/rbs
+	rm -fr ${D}${rbgemdir}/extensions/*/${ruby_version}.0/rbs-*
+	rm -fr ${D}${rbgemdir}/gems/rbs-*
+	rm -f  ${D}${rbgemdir}/specifications/rbs-*.gemspec
+	# rss
+	rm -fr ${D}${rbgemdir}/gems/rss-*
+	rm -f  ${D}${rbgemdir}/specifications/rss-*.gemspec
+	# rexml
+	rm -fr ${D}${rbgemdir}/gems/rexml-*
+	rm -f  ${D}${rbgemdir}/specifications/rexml-*.gemspec
+	# test-unit
+	rm -fr ${D}${rbgemdir}/gems/test-unit-*
+	rm -f  ${D}${rbgemdir}/specifications/test-unit-*.gemspec
+	# typeprof
+	rm -f  ${D}/usr/bin/typeprof
+	rm -fr ${D}${rbgemdir}/gems/typeprof-*
+	rm -f  ${D}${rbgemdir}/specifications/typeprof-*.gemspec
+
 	# rdoc
 	rm -f ${D}/usr/bin/{rdoc,ri}
 	rm -f ${D}/usr/share/man/man1/ri.*
 	rm -fr ${D}${rblibdir}/rdoc*
 	rm -fr ${D}${rbgemdir}/gems/rdoc-*
 	rm -f  ${D}${rbgemdir}/specifications/default/rdoc-*.gemspec
-	# test-unit
-	rm -fr ${D}${rbgemdir}/gems/test-unit-*
-	rm -f  ${D}${rbgemdir}/specifications/test-unit-*
-	# xmlrpc (since 2.4)
-	rm -fr ${D}${rbgemdir}/gems/xmlrpc-*
-	rm -f  ${D}${rbgemdir}/specifications/xmlrpc-*.gemspec
 
 	rm -f ${D}/usr/lib/libruby*-static.a
 	dosym libruby${ruby_version//\./}0.dll.a /usr/lib/libruby.dll.a
